@@ -1,6 +1,5 @@
 package CIF::Client::Plugin::Raw;
 use base 'CIF::Client::Plugin::Output';
-use CIF::Client::Support qw(confor);
 
 require JSON;
 
@@ -9,9 +8,6 @@ sub write_out {
     my $config = shift;
     my $feed = shift;
     my $json;
-    
-    my @config_search_path = ('claoverride',  $feed->{'query'}, 'client' );
-    
     if(1 || $config->{'stream'}){
         my @array = @{$feed->{'feed'}->{'entry'}};
         return unless(keys(%{$array[0]}));
